# ServiceForwarderStatsGroup

An array that contains a group of stats pertaining to ServiceForwarder.  A group of stats would comprise a list of ServiceForwarder  stats managed by an entity, such as an AgentConnector. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**value** | [**[ServiceForwarderStats]**](ServiceForwarderStats.md) | An array that contains a group of stats pertaining to ServiceForwarder.  A group of stats would comprise a list of ServiceForwarder  stats managed by an entity, such as an AgentConnector.  | 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


